Installation — django-nomadlytics 0.1 documentation

### Navigation

- index
- next |
- previous |
- django-nomadlytics 0.1 documentation »

# Installation

## Dependencies

- libsaas: django-nomadlytics uses this app to push the events to track to the different services.
- django-celery (optional): if you want to track events asynchronously (recommended)

## Initial setup

The package is listed in the Python Package Index. You can use your favorite package manager like `easy_install` or `pip`:

    pip install django-nomadlytics

Or, you can clone the latest development code from its repository:

    git clone git@github.com:Nomadblue/django-nomadlytics.git

Add `nomadlytics` to the `INSTALLED_APPS` setting of your `settings.py`:

    INSTALLED_APPS = (
        ...
        'nomadlytics',
    )

### Navigation

- index
- next |
- previous |
- django-nomadlytics 0.1 documentation »